import cockpit from "cockpit";

export async function getAllCountryCodes () {
    try {
        const fileContent = await cockpit.file("/usr/share/zoneinfo/iso3166.tab")
            .read();
        const countryCodes = fileContent.split("\n")
            .map(line => {
                const entries = line.split("\t");
                return entries[0] + " " + entries[1];
            })
            .filter(function (entry) {
                return entry !== "" && entry[0] !== "#" && entry.trim() !== "undefined";
            });
        return [...new Set(countryCodes.slice(countryCodes.indexOf("#code") + 1))];
    } catch (error) {
        console.error("An error occurred while loading wlan country codes.", error);
        throw new Error("An error occurred while loading country codes: " + error);
    }
}

export async function getCurrentCountryCode () {
    try {
        const code = await cockpit.spawn(["raspi-config", "nonint", "get_wifi_country"], { superuser: "required" });
        return code;
    } catch (e) {
        console.log("raspi-config exited with code 1; setting country code to an empty string.");
        return "";
    }
}

export async function setNewCountryCode (newCode) {
    try {
        await cockpit.spawn(["raspi-config", "nonint", "do_wifi_country", newCode], { superuser: "require" });
    } catch (e) {
        console.error("Could not set the new wlan country.", e);
        throw new Error("Could not set the new wlan country.");
    }
}
